[![PyPI](https://img.shields.io/pypi/v/pyffstream.svg)](https://pypi.org/project/pyffstream/) [![Tox](https://github.com/gbeauregard/pyffstream/workflows/Tox/badge.svg)](https://github.com/GBeauregard/pyffstream/actions/workflows/tox.yml) [![CodeQL](https://github.com/gbeauregard/pyffstream/workflows/CodeQL/badge.svg)](https://github.com/GBeauregard/pyffstream/actions/workflows/codeql-analysis.yml)


# pyffstream

A CLI wrapper for ffmpeg to stream files over SRT/RTMP. Also supports the api
for a not (yet) open sourced pyffserver endpoint.
